new_robust2sls: Constructor of robust2sls class
Description
new_robust2sls turns a list into an object of class
"robust2sls"
Usage
new_robust2sls(x = list())
Value
new_robust2sls returns an object of class "robust2sls",
which is a list with a special structure of named components.
Arguments
- x
A list with components of the "robust2sls" class.
Warning
Only checks that the input is a list but not that its components match the
requirements of the "robust2sls" class. Use the validator function
validate_robust2sls for that purpose.