outliers: Number of outliers
Description
outliers calculates the number of outliers from a "robust2sls"
object for a given iteration.
Usage
outliers(robust2sls_object, iteration)
Value
outliers returns the number of outliers for a given iteration
as determined by the outlier-detection algorithm.
Arguments
- robust2sls_object
An object of class "robust2sls".
- iteration
An integer >= 0 representing the iteration for which the
outliers are calculated.