outliers_prop calculates the proportion of outliers relative to all
non-missing observations in the full sample from a "robust2sls" object
for a given iteration.
outliers_prop(robust2sls_object, iteration)outliers_prop returns the proportion of outliers for a given
iteration as determined by the outlier-detection algorithm.
An object of class "robust2sls".
An integer >= 0 representing the iteration for which the outliers are calculated.